==> ejc-supbid-api-3.0.1-20220115.060612-122-sources.jar: com/ejianc/business/supbid/sub/vo/SubSchemeVO.java <==
package com.ejianc.business.supbid.sub.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 分包方案实体
 * 
 * @author generator
 * 
 */
@ApiModel("分包方案实体")
public class SubSchemeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private Long noticeId;
    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("方案名称")
    private String schemeName;
    @ApiModelProperty("报价总额")
    private BigDecimal money;
    @ApiModelProperty("报价总额(含税)")
    private BigDecimal moneyTax;
    
    @ApiModelProperty("分包报价明细实体")
    private List<SubSchemeDetailVO> subSchemeDetailList = new ArrayList<>();

    /**
     * 主表主键
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案名称
     */
    public String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    /**
     * 报价总额
     */
    public BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    
     /**
      * 分包报价明细实体
      */
      public List<SubSchemeDetailVO> getSubSchemeDetailList() {
         return subSchemeDetailList;
      }
     /**
      * 分包报价明细实体
      */
     public void setSubSchemeDetailList(List<SubSchemeDetailVO> subSchemeDetailList) {
         this.subSchemeDetailList = subSchemeDetailList;
     }
}

==> ejc-supbid-api-3.0.1-20230720.080457-224-sources.jar: com/ejianc/business/supbid/sub/vo/SubSchemeVO.java <==
package com.ejianc.business.supbid.sub.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 分包方案实体
 * 
 * @author generator
 * 
 */
@ApiModel("分包方案实体")
public class SubSchemeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private Long noticeId;
    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("方案名称")
    private String schemeName;
//    @ApiModelProperty("报价总额")
//    private BigDecimal money;
//    @ApiModelProperty("报价总额(含税)")
//    private BigDecimal moneyTax;
    @ApiModelProperty("报价总额")
    private BigDecimal mny;
    @ApiModelProperty("报价总额(含税)")
    private BigDecimal taxMny;
    
    @ApiModelProperty("分包报价明细实体")
    private List<SubSchemeDetailVO> subSchemeDetailList = new ArrayList<>();

    /**
     * 主表主键
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案名称
     */
    public String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    /**
      * 分包报价明细实体
      */
      public List<SubSchemeDetailVO> getSubSchemeDetailList() {
         return subSchemeDetailList;
      }
     /**
      * 分包报价明细实体
      */
     public void setSubSchemeDetailList(List<SubSchemeDetailVO> subSchemeDetailList) {
         this.subSchemeDetailList = subSchemeDetailList;
     }
}
